<?php
/** DomFramework
  * @package domframework
  * @author Dominique Fournier <dominique@fournier38.fr>
  */

/** Test the domframework REST part */
class restTest extends PHPUnit_Framework_TestCase
{
  /** No param, JSON by default
    */
  public function testChooseType1 ()
  {
    $rest = new \rest ();
    $res = $rest->chooseType ();
    $this->assertSame ($res, "json");
  }

  /** If limited allowedTypes, return the first one as default
    */
  public function testChooseType2 ()
  {
    $rest = new \rest ();
    $rest->allowedtypes = array ("xml", "csv");
    $res = $rest->chooseType ();
    $this->assertSame ($res, "xml");
  }

  /** Choose by the user specification : exact match
    */
  public function testChooseType3 ()
  {
    $rest = new \rest ();
    $_SERVER["HTTP_ACCEPT"] = "text/html,application/xml;q=0.9,*/*;q=0.8";
    $res = $rest->chooseType ();
    $this->assertSame ($res, "xml");
  }

  /** Choose by the user specification : generic match
    */
  public function testChooseType4 ()
  {
    $rest = new \rest ();
    $_SERVER["HTTP_ACCEPT"] = "text/html;q=0.9,*/*;q=0.8";
    $res = $rest->chooseType ();
    $this->assertSame ($res, "json");
  }

  /** Choose by the user specification : generic match with limited allowed
    * types
    */
  public function testChooseType5 ()
  {
    $rest = new \rest ();
    $rest->allowedtypes = array ("xml", "csv");
    $_SERVER["HTTP_ACCEPT"] = "text/html;q=0.9,*/*;q=0.8";
    $res = $rest->chooseType ();
    $this->assertSame ($res, "xml");
  }
}
